@@ -1,5 +1,5 @@
 /* Zutils - Utilities dealing with compressed files
-   Copyright (C) 2009-2023 Antonio Diaz Diaz.
+   Copyright (C) 2009-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ int verbosity = 0;
 namespace {
 
 const char * const config_file_name = "zutils.conf";
-const char * const     program_year = "2023";
+const char * const     program_year = "2024";
 
 std::string compressor_names[num_formats] =
   { "bzip2", "gzip", "lzip", "xz", "zstd" };	// default compressor names
@@ -46,7 +46,7 @@ std::string compressor_names[num_formats] =
 std::vector< std::string > compressor_args[num_formats];
 
 // vector of enabled formats plus [num_formats] for uncompressed.
-// empty means all enabled.
+// empty or incomplete (size <= num_formats) means all enabled.
 std::vector< bool > enabled_formats;
 
 const struct { const char * from; const char * to; int format_index; }
@@ -292,7 +292,7 @@ int extension_format( const int eindex )
   { return ( eindex >= 0 ) ? known_extensions[eindex].format_index : -1; }
 
 const char * extension_from( const int eindex )
-  { return known_extensions[eindex].from; }
+  { return ( eindex >= 0 ) ? known_extensions[eindex].from : ""; }
 
 const char * extension_to( const int eindex )
   { return known_extensions[eindex].to; }
