@@ -1,5 +1,5 @@
 /* Zutils - Utilities dealing with compressed files
-   Copyright (C) 2009-2023 Antonio Diaz Diaz.
+   Copyright (C) 2009-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ const char * const format_names[num_formats] =
 const char * const simple_extensions[num_formats] =
   { ".bz2", ".gz", ".lz", ".xz", ".zst" };
 const int format_order[num_formats] =
-  { fmt_lz, fmt_bz2, fmt_gz, fmt_zst, fmt_xz };		// search order
+  { fmt_lz, fmt_gz, fmt_bz2, fmt_zst, fmt_xz };		// search order
 
 bool enabled_format( const int format_index );		// -1 == uncompressed
 void parse_format_list( const std::string & arg, const char * const pn );
@@ -33,7 +33,7 @@ int parse_format_type( const std::string & arg, const char * const pn,
 
 int extension_index( const std::string & name );	// -1 if unknown
 int extension_format( const int eindex );		// -1 if uncompressed
-const char * extension_from( const int eindex );
+const char * extension_from( const int eindex );	// -1 if uncompressed
 const char * extension_to( const int eindex );
 
 // Return format_index, or -1 if uncompressed.
