@@ -1,5 +1,5 @@
 /* Zutils - Utilities dealing with compressed files
-   Copyright (C) 2009-2023 Antonio Diaz Diaz.
+   Copyright (C) 2009-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ bool test_full_name( const std::string & full_name, const struct stat * stp,
         { loop = true; break; }
       }
   if( loop )			// full_name already visited or above tree
-    show_file_error( full_name.c_str(), "warning: Recursive directory loop." );
+    show_file_error( full_name.c_str(), "warning: recursive directory loop." );
   return !loop;			// (link to) directory
   }
 
