@@ -1,5 +1,5 @@
 /* Zcat - decompress and concatenate files to standard output
-   Copyright (C) 2010-2023 Antonio Diaz Diaz.
+   Copyright (C) 2010-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -94,8 +94,8 @@ void show_help()
                "file given is compressed, its decompressed content is copied. If a file\n"
                "given does not exist, and its name does not end with one of the known\n"
                "extensions, zcat tries the compressed file names corresponding to the\n"
-               "formats supported. If a file fails to decompress, zcat continues copying the\n"
-               "rest of the files.\n"
+               "formats supported until one is found. If a file fails to decompress, zcat\n"
+               "continues copying the rest of the files.\n"
                "\nIf a file is specified as '-', data are read from standard input,\n"
                "decompressed if needed, and sent to standard output. Data read from\n"
                "standard input must be of the same type; all uncompressed or all in the\n"
@@ -345,7 +345,7 @@ int main( const int argc, const char * const argv[] )
       case lz_opt: parse_compressor( arg, pn, fmt_lz, 1 ); break;
       case xz_opt: parse_compressor( arg, pn, fmt_xz, 1 ); break;
       case zst_opt: parse_compressor( arg, pn, fmt_zst, 1 ); break;
-      default : internal_error( "uncaught option." );
+      default: internal_error( "uncaught option." );
       }
     } // end process options
 
