@@ -1,5 +1,5 @@
 /* Zdiff - decompress and compare two files line by line
-   Copyright (C) 2010-2023 Antonio Diaz Diaz.
+   Copyright (C) 2010-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -57,13 +57,10 @@ void show_help()
                "\nThe formats supported are bzip2, gzip, lzip, xz, and zstd.\n"
                "\nUsage: zdiff [options] file1 [file2]\n"
                "\nzdiff compares file1 to file2. The standard input is used only if file1 or\n"
-               "file2 refers to standard input. If file2 is omitted zdiff tries the\n"
-               "following:\n"
-               "\n  - If file1 is compressed, compares its decompressed contents with\n"
-               "  the corresponding uncompressed file (the name of file1 with the\n"
-               "  extension removed).\n"
-               "\n  - If file1 is uncompressed, compares it with the decompressed\n"
-               "  contents of file1.[lz|bz2|gz|zst|xz] (the first one that is found).\n"
+               "file2 refers to standard input. If file2 is omitted zdiff tries to compare\n"
+               "file1 with the corresponding uncompressed file (if file1 is compressed), and\n"
+               "then with the corresponding compressed files of the remaining formats until\n"
+               "one is found.\n"
                "\nExit status is 0 if inputs are identical, 1 if different, 2 if trouble.\n"
                "Some options only work if the diff program used supports them.\n"
                "\nOptions:\n"
@@ -76,7 +73,7 @@ void show_help()
                "  -C, --context=<n>                 same as -c but use <n> lines of context\n"
                "  -d, --minimal                     try hard to find a smaller set of changes\n"
                "  -E, --ignore-tab-expansion        ignore changes due to tab expansion\n"
-               "  -i, --ignore-case                 ignore case differences in file contents\n"
+               "  -i, --ignore-case                 ignore case differences\n"
                "  -M, --format=<list>               process only the formats in <list>\n"
                "  -N, --no-rcfile                   don't read runtime configuration file\n"
                "  -O, --force-format=[<f1>][,<f2>]  force one or both input formats\n"
@@ -344,7 +341,7 @@ int main( const int argc, const char * const argv[] )
       case lz_opt: parse_compressor( sarg, pn, fmt_lz ); break;
       case xz_opt: parse_compressor( sarg, pn, fmt_xz ); break;
       case zst_opt: parse_compressor( sarg, pn, fmt_zst ); break;
-      default : internal_error( "uncaught option." );
+      default: internal_error( "uncaught option." );
       }
     } // end process options
 
